using System;
using System.IO;
using System.Xml;
using Ellisys.Platform.NetworkRemoteControl.Analyzer;

namespace RemoteControl_Analyzer_Sample;

class Program
{
	// TODO: Please adapt the following constants to your needs
	private const string HostIp = "localhost";
	private const int HostPort = 12345;

	private static void Main(string[] args)
	{
		using var ice = Ice.Util.initialize(ref args);
		var remoteControl = CreateRemoteControlProxy(ice);

		Console.WriteLine("Remote control connection succeeded.");

		Console.WriteLine("Creating CSV output from currently open trace...");

		using (var writer = File.CreateText("export.csv"))
		{
			Tools.ExportToCsv(remoteControl, writer);
		}

		remoteControl.ReleaseAllOverviewItemHandles();
	}

	private static AnalyzerRemoteControlPrx CreateRemoteControlProxy(Ice.Communicator communicator)
	{
		var proxyString = $"{AnalyzerRemoteControlIdentity.value}:tcp -h {HostIp} -p {HostPort}";
		var remoteControl = AnalyzerRemoteControlPrxHelper.checkedCast(communicator.stringToProxy(proxyString));

		if(remoteControl == null)
		{
			throw new ApplicationException("Invalid proxy " + proxyString);
		}

		return remoteControl;
	}
}

static class Tools
{
	public static void ExportToCsv(AnalyzerRemoteControlPrx remoteControl, StreamWriter writer)
	{
		var rootHandle = remoteControl.OverviewRootItem();
		var rootChildCount = remoteControl.GetOverviewItemChildCount(rootHandle);

		var first = true;
		var xmlDocument = new XmlDocument();

		for(var i = 0; i < rootChildCount; i++)
		{
			var childHandle = remoteControl.GetOverviewItemChild(rootHandle, i);
			var childXmlReport = remoteControl.GetOverviewItemXmlReportFiltered(childHandle, new [] { "Overview Columns" });
			xmlDocument.LoadXml(childXmlReport);

			if(first)
			{
				// Add title line
				foreach(XmlElement column in xmlDocument["Details"]["Item"])
				{
					writer.Write("\"");
					writer.Write(column.GetAttribute("name"));
					writer.Write("\",");
				}

				writer.WriteLine();

				first = false;
			}

			foreach(XmlElement column in xmlDocument["Details"]["Item"])
			{
				writer.Write("\"");
				writer.Write(column.GetAttribute("value"));
				writer.Write("\",");
			}

			writer.WriteLine();
		}
	}
}