#ifndef _ELLISYS_BT_ANALYZER_REMOTE_CONTROL_ICE
#define _ELLISYS_BT_ANALYZER_REMOTE_CONTROL_ICE

#include "AnalyzerRemoteControl.ice"

module Ellisys
{
	module Platform
	{
		module NetworkRemoteControl
		{
			module Analyzer
			{
				const string BluetoothAnalyzerRemoteControlIdentity = "Ellisys.AnalyzerRemoteControl.Bluetooth";
			
				sequence<byte> LinkKeyByteArray;
				sequence<long> DeviceAddressArray;
				sequence<double> RssiArray;

				enum DeviceFilterMode
				{
					KeepAll,
					ExcludeBackground,
					KeepOnly,
					KeepInvolving
				};

				struct ChannelSummary
				{
					long Ok;
					long Retransmitted;
					long PayloadError;
					long HeaderError;
					long NotApplicable;
				};

				sequence<ChannelSummary> ChannelsSummary;

				interface BluetoothAnalyzerRemoteControl extends AnalyzerRemoteControl
				{
					void SplitTraceFileAndContinueRecording(string filename) throws OperationFailed;

					void AddLinkKey(long bdaddr1, long bdaddr2, LinkKeyByteArray linkKey) throws OperationFailed;

					void ConfigureDeviceFilter(DeviceFilterMode mode, DeviceAddressArray deviceAddrs) throws OperationFailed;

					void GetSpectrumRssi(long timeInPicoseconds, int rfChannelNumber, out double rssi, out long startTimeInPicoseconds, out long stopTimeInPicoseconds) throws OperationFailed;
					void GetSpectrumRssiRange(long fromTimeInPicoseconds, long toTimeInPicoseconds, int rfChannelNumber, out RssiArray rssi, out long startTimeInPicoseconds, out long stopTimeInPicoseconds) throws OperationFailed;

					ChannelsSummary GetChannelsSummary(long fromTimeInPicoseconds, long toTimeInPicoseconds);

					void ExportAudio(string outputDirectory);
				};
			};
		};
	};
};

#endif 
